@@ -14,7 +14,9 @@
 
 import os
 import pathlib
+from gaarf.utils import get_customer_ids
 
+from .hooks import GaarfHook
 from .operators import GaarfOperator, GaarfBqOperator
 
 
@@ -22,6 +24,18 @@ def get_query_basename(query_path: pathlib.Path) -> str:
     return os.path.basename(query_path)[:-4]
 
 
+class GaarfMccExpander:
+
+    def __init__(self,
+                 google_ads_conn_id: str = "google_ads_default",
+                 api_version: str = "v12") -> None:
+        self.client = GaarfHook(google_ads_conn_id=google_ads_conn_id,
+                                api_version=api_version)
+
+    def expand_seed_customer_id(self, customer_id: str) -> List[str]:
+        return get_customer_ids(self.client.get_client, customer_id)
+
+
 class GaarfExecutor:
 
     def __init__(self,
